'use client';

import type React from 'react';

import { useState } from 'react';
import { useRouter } from 'next/navigation';
import { useCheckoutStore } from '@/store/useCheckoutStore';
import { useCartStore } from '@/store/useCartStore';
import { toast } from 'react-hot-toast';
import { generateOrderNumber } from '@/lib/utils';

const indianStates = [
  'Andhra Pradesh',
  'Arunachal Pradesh',
  'Assam',
  'Bihar',
  'Chhattisgarh',
  'Goa',
  'Gujarat',
  'Haryana',
  'Himachal Pradesh',
  'Jharkhand',
  'Karnataka',
  'Kerala',
  'Madhya Pradesh',
  'Maharashtra',
  'Manipur',
  'Meghalaya',
  'Mizoram',
  'Nagaland',
  'Odisha',
  'Punjab',
  'Rajasthan',
  'Sikkim',
  'Tamil Nadu',
  'Telangana',
  'Tripura',
  'Uttar Pradesh',
  'Uttarakhand',
  'West Bengal',
];

export default function CheckoutPage() {
  const router = useRouter();
  const { items, coupon, total, discountedTotal } = useCartStore();
  const checkoutStore = useCheckoutStore();
  const [isSubmitting, setIsSubmitting] = useState(false);

  const prepareRequestBody = () => {
    const {
      firstName,
      lastName,
      streetAddress,
      apartment,
      city,
      state,
      pinCode,
      email,
      phone,
      notes,
    } = checkoutStore;

    const shippingAddress = checkoutStore.deliverToDifferentAddress
      ? {
          FullName: `${checkoutStore.differentAddress.firstName} ${checkoutStore.differentAddress.lastName}`,
          Address:
            `${checkoutStore.differentAddress.streetAddress} ${checkoutStore.differentAddress.apartment}`.trim(),
          City: checkoutStore.differentAddress.city,
          PostalCode: checkoutStore.differentAddress.pinCode,
          Email: email, // Assuming email and phone are the same for shipping
          Phone: phone,
          Country: 'India',
        }
      : {
          FullName: `${firstName} ${lastName}`,
          Address: `${streetAddress} ${apartment}`.trim(),
          City: city,
          PostalCode: pinCode,
          Email: email,
          Phone: phone,
          Country: 'India',
        };

    return {
      email: email,
      orderid: generateOrderNumber(),
      cart: items.map((item) => ({
        productId: item.id,
        sku: item.sku,
        quantity: item.quantity,
        cost: Number.parseFloat(item.price),
        tax: (Number.parseFloat(item.price) * 28) / 100,
        total:
          Number.parseFloat(item.price) +
          (Number.parseFloat(item.price) * 28) / 100,
      })),
      billingAddress: {
        FullName: `${firstName} ${lastName}`,
        Address: `${streetAddress} ${apartment}`.trim(),
        City: city,
        PostalCode: pinCode,
        Email: email,
        Phone: phone,
        Country: 'India',
      },
      shippingAddress: shippingAddress, // Use the dynamically generated shipping address
      name: `${firstName} ${lastName}`,
      amount: coupon ? discountedTotal().toFixed(0) : total().toFixed(0),
      coupon: coupon?.code,
      CustomerNote: notes,
      OrderDate: Date.now(),
    };
  };

  const handleSubmit = async (e: React.FormEvent) => {
    e.preventDefault();
    setIsSubmitting(true);

    if (items.length === 0) {
      toast.error('Your cart is empty. Please add items before checking out.');
      setIsSubmitting(false);
      return;
    }

    const requestBody = prepareRequestBody();

    try {
      const response = await fetch(
        process?.env?.NEXT_PUBLIC_PROD_API_URL + '/api/v1/orders/payment',
        {
          method: 'POST',
          headers: {
            'Content-Type': 'application/json',
          },
          body: JSON.stringify(requestBody),
        }
      );

      if (response.ok) {
        const result = await response.json();
        console.log(result);

        if (result && result.paymentUrl) {
          if (result.orderId) {
            localStorage.setItem('currentOrderId', result.orderId);
          }

          useCartStore.getState().clearCart();

          window.location.href = result.paymentUrl;
        } else {
          throw new Error('Payment initialization failed: Missing payment URL');
        }
      } else {
        const errorData = await response.json();
        throw new Error(errorData.error?.message || 'Payment failed');
      }
    } catch (error) {
      console.error('Error during checkout:', error);
      toast.error(
        error instanceof Error
          ? error.message
          : 'Payment failed. Please try again.'
      );
      router.push('/checkout');
    } finally {
      setIsSubmitting(false);
    }
  };
  return (
    <div className='container mx-auto p-4'>
      <h1 className='text-2xl font-bold mb-4'>Checkout</h1>

      {items.length === 0 ? (
        <div className='bg-yellow-50 border border-yellow-200 rounded-md p-6 text-center'>
          <h2 className='text-xl font-semibold text-yellow-700 mb-3'>
            Your cart is empty
          </h2>
          <p className='text-gray-600 mb-4'>
            Please add some products to your cart before proceeding to checkout.
          </p>
          <button
            onClick={() => router.push('/products')}
            className='bg-blue-500 text-white px-6 py-2 rounded hover:bg-blue-600 transition-colors'
          >
            Browse Products
          </button>
        </div>
      ) : (
        <form onSubmit={handleSubmit} className='space-y-4'>
          <div className='grid grid-cols-1 md:grid-cols-2 gap-4'>
            <input
              type='text'
              placeholder='First name*'
              required
              className='border p-2 rounded'
              value={checkoutStore.firstName}
              onChange={(e) =>
                checkoutStore.setField('firstName', e.target.value)
              }
            />
            <input
              type='text'
              placeholder='Last name*'
              required
              className='border p-2 rounded'
              value={checkoutStore.lastName}
              onChange={(e) =>
                checkoutStore.setField('lastName', e.target.value)
              }
            />
          </div>
          <input
            type='text'
            placeholder='Company name (optional)'
            className='border p-2 rounded w-full'
            value={checkoutStore.companyName}
            onChange={(e) =>
              checkoutStore.setField('companyName', e.target.value)
            }
          />
          <input
            type='text'
            placeholder='Country/Region*'
            required
            className='border p-2 rounded w-full bg-gray-100'
            value='India'
            readOnly
          />
          <input
            type='text'
            placeholder='House number and street name*'
            required
            className='border p-2 rounded w-full'
            value={checkoutStore.streetAddress}
            onChange={(e) =>
              checkoutStore.setField('streetAddress', e.target.value)
            }
          />
          <input
            type='text'
            placeholder='Apartment, suite, unit, etc. (optional)'
            className='border p-2 rounded w-full'
            value={checkoutStore.apartment}
            onChange={(e) =>
              checkoutStore.setField('apartment', e.target.value)
            }
          />
          <input
            type='text'
            placeholder='Town / City*'
            required
            className='border p-2 rounded w-full'
            value={checkoutStore.city}
            onChange={(e) => checkoutStore.setField('city', e.target.value)}
          />
          <select
            required
            className='border p-2 rounded w-full'
            value={checkoutStore.state}
            onChange={(e) => checkoutStore.setField('state', e.target.value)}
          >
            <option value=''>Select State*</option>
            {indianStates.map((state) => (
              <option key={state} value={state}>
                {state}
              </option>
            ))}
          </select>
          <input
            type='text'
            placeholder='PIN Code*'
            required
            className='border p-2 rounded w-full'
            value={checkoutStore.pinCode}
            onChange={(e) => checkoutStore.setField('pinCode', e.target.value)}
          />
          <div className='flex items-center border p-2 rounded'>
            <span className='mr-2'>🇮🇳 +91</span>
            <input
              type='tel'
              placeholder='Phone*'
              required
              className='flex-grow'
              value={checkoutStore.phone}
              onChange={(e) => checkoutStore.setField('phone', e.target.value)}
            />
          </div>
          <input
            type='email'
            placeholder='Email address*'
            required
            className='border p-2 rounded w-full'
            value={checkoutStore.email}
            onChange={(e) => checkoutStore.setField('email', e.target.value)}
          />
          <div className='flex items-center'>
            <input
              type='checkbox'
              id='createAccount'
              className='mr-2'
              checked={checkoutStore.createAccount}
              onChange={(e) =>
                checkoutStore.setField('createAccount', e.target.checked)
              }
            />
            <label htmlFor='createAccount'>Create account</label>
          </div>
          <div className='flex items-center'>
            <input
              type='checkbox'
              id='deliverToDifferentAddress'
              className='mr-2'
              checked={checkoutStore.deliverToDifferentAddress}
              onChange={(e) =>
                checkoutStore.setField(
                  'deliverToDifferentAddress',
                  e.target.checked
                )
              }
            />
            <label htmlFor='deliverToDifferentAddress'>
              Deliver to different address
            </label>
          </div>
          {checkoutStore.deliverToDifferentAddress && (
            <div className='space-y-4'>
              <div className='grid grid-cols-1 md:grid-cols-2 gap-4'>
                <input
                  type='text'
                  placeholder='First name*'
                  required
                  className='border p-2 rounded'
                  value={checkoutStore.differentAddress.firstName}
                  onChange={(e) =>
                    checkoutStore.setDifferentAddressField(
                      'firstName',
                      e.target.value
                    )
                  }
                />
                <input
                  type='text'
                  placeholder='Last name*'
                  required
                  className='border p-2 rounded'
                  value={checkoutStore.differentAddress.lastName}
                  onChange={(e) =>
                    checkoutStore.setDifferentAddressField(
                      'lastName',
                      e.target.value
                    )
                  }
                />
              </div>
              <input
                type='text'
                placeholder='Company name (optional)'
                className='border p-2 rounded w-full'
                value={checkoutStore.differentAddress.companyName}
                onChange={(e) =>
                  checkoutStore.setDifferentAddressField(
                    'companyName',
                    e.target.value
                  )
                }
              />
              <input
                type='text'
                placeholder='Country/Region*'
                required
                className='border p-2 rounded w-full bg-gray-100'
                value='India'
                readOnly
              />
              <input
                type='text'
                placeholder='House number and street name*'
                required
                className='border p-2 rounded w-full'
                value={checkoutStore.differentAddress.streetAddress}
                onChange={(e) =>
                  checkoutStore.setDifferentAddressField(
                    'streetAddress',
                    e.target.value
                  )
                }
              />
              <input
                type='text'
                placeholder='Apartment, suite, unit, etc. (optional)'
                className='border p-2 rounded w-full'
                value={checkoutStore.differentAddress.apartment}
                onChange={(e) =>
                  checkoutStore.setDifferentAddressField(
                    'apartment',
                    e.target.value
                  )
                }
              />
              <input
                type='text'
                placeholder='Town / City*'
                required
                className='border p-2 rounded w-full'
                value={checkoutStore.differentAddress.city}
                onChange={(e) =>
                  checkoutStore.setDifferentAddressField('city', e.target.value)
                }
              />
              <select
                required
                className='border p-2 rounded w-full'
                value={checkoutStore.differentAddress.state}
                onChange={(e) =>
                  checkoutStore.setDifferentAddressField(
                    'state',
                    e.target.value
                  )
                }
              >
                <option value=''>Select State*</option>
                {indianStates.map((state) => (
                  <option key={state} value={state}>
                    {state}
                  </option>
                ))}
              </select>
              <input
                type='text'
                placeholder='PIN Code*'
                required
                className='border p-2 rounded w-full'
                value={checkoutStore.differentAddress.pinCode}
                onChange={(e) =>
                  checkoutStore.setDifferentAddressField(
                    'pinCode',
                    e.target.value
                  )
                }
              />
            </div>
          )}
          <textarea
            placeholder='Notes (optional)'
            className='border p-2 rounded w-full'
            value={checkoutStore.notes}
            onChange={(e) => checkoutStore.setField('notes', e.target.value)}
          />
          <button
            type='submit'
            className='bg-blue-500 text-white p-2 rounded hover:bg-blue-600'
          >
            Submit
          </button>
        </form>
      )}
      {isSubmitting && (
        <div className='mt-4 p-4 bg-green-100 text-green-700 rounded'>
          Form submitted successfully! Check the console for the payload.
        </div>
      )}
    </div>
  );
}
