"use client";
import Breadcrumbs from "@/components/shared/Breadcrumbs";
import BoxContainer from "@/components/shared/box-container";
import { useState } from "react";
import { yupResolver } from "@hookform/resolvers/yup";
import { useForm } from "react-hook-form";
import * as yup from "yup";
import { Button } from "@/components/ui/button";
import {
  Form,
  FormControl,
  FormField,
  FormItem,
  FormLabel,
  FormMessage,
} from "@/components/ui/form";
import { Input } from "@/components/ui/input";
import toast from "react-hot-toast";
import { useRouter } from "next/navigation";

export default function JoinOurTeamForm() {
  const router = useRouter();

  const [isSubmitting, setIsSubmitting] = useState(false);
  const defaultValues = {
    name: "",
    Phone: "",
    City: "",
    email: "",
    Tyreimage: "",
  };
  const formSchema = yup
    .object({
      name: yup
        .string()
        .required("Full name is required")
        .min(2, "Full name must be at least 2 characters."),
      Phone: yup
        .string()
        .required("Mobile number is required")
        .matches(/^[0-9]{10}$/, "Mobile number must be 10 digits."),
      City: yup
        .string()
        .required("City is required")
        .min(2, "City must be at least 2 characters."),
      email: yup
        .string()
        .required("Email is required")
        .email("Please enter a valid email address."),
      Tyreimage: yup.string().optional(),
    })
    .required();

  const form = useForm<yup.InferType<typeof formSchema>>({
    resolver: yupResolver(formSchema),
    defaultValues,
  });

  async function onSubmit(values: yup.InferType<typeof formSchema>) {
    setIsSubmitting(true);
    try {
      const response = await fetch(
        "https://tyrefinder.co.in/api/job-applications",
        {
          method: "POST",
          headers: {
            "Content-Type": "application/json",
          },
          body: JSON.stringify({ data: values }),
        }
      );

      if (response.ok) {
        form.reset(defaultValues);
        toast.success(
          "Form submitted successfully, We'll get back to you soon!",
          { duration: 4000, position: "top-right" }
        );
        router.push("/two-wheeler-tyre");
      } else {
        const errorData = await response.json();
        throw new Error(errorData.error?.message || "Something went wrong");
      }
    } catch (error) {
      toast.error(
        error instanceof Error
          ? error.message
          : "Something went wrong. Please try again.",
        { duration: 4000, position: "top-right" }
      );
    } finally {
      setIsSubmitting(false);
    }
  }

  return (
    <div className="">
      <div className="mb-5">
        <Breadcrumbs />
      </div>
      <div className="bg-tegblue">
        <h1 className="text-center text-3xl text-white p-8 font-semibold">
          JOIN OUR TEAM
        </h1>
      </div>
      <div className="py-10">
        <BoxContainer>
          {" "}
          <Form {...form}>
            <form
              onSubmit={form.handleSubmit(onSubmit)}
              className="space-y-6 max-w-4xl mx-auto"
            >
              <div className="grid grid-cols-1 md:grid-cols-2 gap-6">
                <FormField
                  control={form.control}
                  name="name"
                  render={({ field }) => (
                    <FormItem>
                      <FormLabel className="text-gray-400">Full Name</FormLabel>
                      <FormControl>
                        <Input
                          placeholder=""
                          {...field}
                          type="text"
                          className="focus:ring-0 focus:ring-offset-0"
                        />
                      </FormControl>
                      <FormMessage />
                    </FormItem>
                  )}
                />

                <FormField
                  control={form.control}
                  name="Phone"
                  render={({ field }) => (
                    <FormItem>
                      <FormLabel className="text-gray-400">Mobile</FormLabel>
                      <FormControl>
                        <Input
                          placeholder=""
                          type="tel"
                          {...field}
                          className="focus:ring-0 focus:ring-offset-0"
                        />
                      </FormControl>
                      <FormMessage />
                    </FormItem>
                  )}
                />

                <FormField
                  control={form.control}
                  name="City"
                  render={({ field }) => (
                    <FormItem>
                      <FormLabel className="text-gray-400">City</FormLabel>
                      <FormControl>
                        <Input
                          placeholder=""
                          {...field}
                          type="text"
                          className="focus:ring-0 focus:ring-offset-0"
                        />
                      </FormControl>
                      <FormMessage />
                    </FormItem>
                  )}
                />

                <FormField
                  control={form.control}
                  name="email"
                  render={({ field }) => (
                    <FormItem>
                      <FormLabel className="text-gray-400">Email</FormLabel>
                      <FormControl>
                        <Input
                          placeholder=""
                          type="email"
                          {...field}
                          className="focus:ring-0 focus:ring-offset-0"
                        />
                      </FormControl>
                      <FormMessage />
                    </FormItem>
                  )}
                />
                <FormField
                  control={form.control}
                  name="Tyreimage"
                  render={({ field }) => (
                    <FormItem>
                      <FormLabel className="text-gray-400">
                        Upload Tyre Images Less than 1MB in JPG format only
                      </FormLabel>
                      <Input placeholder="" type="file" {...field} />
                    </FormItem>
                  )}
                />
              </div>

              <div className="flex justify-center">
                <Button
                  type="submit"
                  disabled={isSubmitting}
                  className="px-10 bg-gray-400 hover:bg-gray-500"
                >
                  {isSubmitting ? "SENDING..." : "SEND"}
                </Button>
              </div>
            </form>
          </Form>
        </BoxContainer>
      </div>
    </div>
  );
}
