import Link from 'next/link';
import { CheckCircle } from 'lucide-react';
import { Button } from '@/components/ui/button';
import { Card, CardContent, CardHeader, CardTitle } from '@/components/ui/card';
import { Separator } from '@/components/ui/separator';

// Define the order data type
interface OrderData {
  id: number;
  orderid: string;
  email: string;
  paymentInfo: {
    CURRENCY: string;
    GATEWAYNAME: string;
    RESPMSG: string;
    BANKNAME: string;
    PAYMENTMODE: string;
    CUSTID: string;
    MID: string;
    MERC_UNQ_REF: string;
    RESPCODE: string;
    TXNID: string;
    TXNAMOUNT: string;
    ORDERID: string;
    STATUS: string;
    BANKTXNID: string;
    TXNDATETIME: string;
    TXNDATE: string;
  } | null;
  name: string;
  transactionid: string | null;
  amount: number;
  status: string;
  createdAt: string;
  updatedAt: string;
  publishedAt: string | null;
  coupon: string | null;
  OrderDate: string | null;
  CustomerNote: string | null;
  products: Array<{
    id: number;
    title: string;
    sku: string;
    price: number;
    regularPrice?: number;
    salePrice?: number;
    content?: string;
    shortdescription?: string;
    slug?: string;
    createdAt?: string;
    updatedAt?: string;
    publishedAt?: string;
    stockStatus?: string;
    ProductVisibility?: string;
    WheelPosition?: string;
  }>;
  billingAddress: {
    id?: number;
    FullName: string;
    Address: string;
    City: string;
    PostalCode: string;
    Email: string;
    Phone: string;
    Country: string;
  } | null;
  shippingAddress: {
    id?: number;
    FullName: string;
    Address: string;
    City: string;
    PostalCode: string;
    Email: string;
    Phone: string;
    Country: string;
  } | null;
}

// Add console.log to debug the API response
async function getOrderData(orderId: string): Promise<OrderData | null> {
  try {
    const response = await fetch(
      `${process?.env?.PROD_API_URL}/api/v1/orders/${orderId}`,
      {
        cache: 'no-store',
      }
    );

    if (!response.ok) {
      console.error('Failed to fetch order data');
      return null;
    }

    const data = await response.json();
    // console.log('API Response:', data); // Debug log
    return data;
  } catch (error) {
    console.error('Error fetching order data:', error);
    return null;
  }
}

// In the component, add a debug section to see what data we have
export default async function OrderSuccessPage({
  searchParams,
}: {
  searchParams: { orderid?: string };
}) {
  // Get the order ID from query parameters
  const orderId = searchParams.orderid;

  // Check if order ID exists
  const hasOrderId = !!orderId;

  // Fetch order data if order ID exists
  const orderData = hasOrderId && orderId ? await getOrderData(orderId) : null;

  // Debug log
  // console.log('Order Data in component:', orderData);

  return (
    <div className='container max-w-3xl mx-auto px-4 py-8 md:py-12'>
      {/* Order Status Header */}
      <div className='text-center mb-8'>
        <div className='inline-flex items-center justify-center w-16 h-16 rounded-full bg-primary/10 mb-4'>
          <CheckCircle className='w-8 h-8 text-primary' />
        </div>
        <h1 className='text-2xl md:text-3xl font-bold text-center mb-2'>
          {hasOrderId ? 'ORDER RECEIVED' : 'NO ORDER FOUND'}
        </h1>
      </div>

      {hasOrderId ? (
        <>
          {/* Thank You Message */}
          <Card className='mb-8'>
            <CardContent className='pt-6'>
              <p className='mb-4'>Dear Customer,</p>
              <p className='text-muted-foreground mb-6'>
                Thanks for ordering with TVS Eurogrip. Your order will be
                processed in next 24 hrs and we will update you the status on
                your registered email ID.
              </p>
              <div className='text-sm text-muted-foreground'>
                <p>For any information about the order, contact</p>
                <p className='font-medium text-foreground'>+917845878422</p>
                <p>or email to</p>
                <p className='font-medium text-foreground'>
                  support@eurogriptyres.com
                </p>
              </div>
            </CardContent>
          </Card>

          {/* Order Information */}
          <Card className='mb-8'>
            <CardHeader>
              <CardTitle>Order Information</CardTitle>
            </CardHeader>
            <CardContent>
              <dl className='grid grid-cols-1 md:grid-cols-2 gap-4 text-sm'>
                <div>
                  <dt className='text-muted-foreground'>Order number:</dt>
                  <dd className='font-medium'>{orderData?.orderid}</dd>
                </div>
                {orderData?.paymentInfo?.TXNDATE && (
                  <div>
                    <dt className='text-muted-foreground'>Date:</dt>
                    <dd className='font-medium'>
                      {orderData.paymentInfo.TXNDATE}
                    </dd>
                  </div>
                )}
                <div>
                  <dt className='text-muted-foreground'>Payment method:</dt>
                  <dd className='font-medium'>
                    {orderData?.paymentInfo?.PAYMENTMODE
                      ? `${orderData.paymentInfo.PAYMENTMODE}${
                          orderData.paymentInfo.BANKNAME
                            ? ` (${orderData.paymentInfo.BANKNAME})`
                            : ''
                        }`
                      : 'Paytm Payment Gateway'}
                  </dd>
                </div>
                {orderData?.status && (
                  <div>
                    <dt className='text-muted-foreground'>Status:</dt>
                    <dd className='font-medium'>{orderData.status}</dd>
                  </div>
                )}
                {orderData?.coupon && (
                  <div>
                    <dt className='text-muted-foreground'>Coupon:</dt>
                    <dd className='font-medium'>{orderData.coupon}</dd>
                  </div>
                )}
                {orderData?.transactionid && (
                  <div>
                    <dt className='text-muted-foreground'>Transaction ID:</dt>
                    <dd className='font-medium text-xs md:text-sm font-mono'>
                      {orderData.transactionid}
                    </dd>
                  </div>
                )}
                {orderData?.amount && (
                  <div>
                    <dt className='text-muted-foreground'>Amount:</dt>
                    <dd className='font-medium'>
                      ₹{orderData.amount.toFixed(2)}
                    </dd>
                  </div>
                )}
              </dl>
            </CardContent>
          </Card>

          {/* Customer Information */}
          {orderData && (orderData.name || orderData.email) && (
            <Card className='mb-8'>
              <CardHeader>
                <CardTitle>Customer Information</CardTitle>
              </CardHeader>
              <CardContent>
                <dl className='grid grid-cols-1 md:grid-cols-2 gap-4 text-sm'>
                  {orderData.name && (
                    <div>
                      <dt className='text-muted-foreground'>Name:</dt>
                      <dd className='font-medium'>{orderData.name}</dd>
                    </div>
                  )}
                  {orderData.email && (
                    <div>
                      <dt className='text-muted-foreground'>Email:</dt>
                      <dd className='font-medium'>{orderData.email}</dd>
                    </div>
                  )}
                  {orderData.CustomerNote && (
                    <div className='col-span-2'>
                      <dt className='text-muted-foreground'>Customer Note:</dt>
                      <dd className='font-medium'>{orderData.CustomerNote}</dd>
                    </div>
                  )}
                </dl>
              </CardContent>
            </Card>
          )}

          {/* Shipping & Billing Address */}
          {orderData &&
            (orderData.shippingAddress || orderData.billingAddress) && (
              <Card className='mb-8'>
                <CardHeader>
                  <CardTitle>Address Information</CardTitle>
                </CardHeader>
                <CardContent>
                  <div className='grid grid-cols-1 md:grid-cols-2 gap-6'>
                    {orderData.shippingAddress && (
                      <div>
                        <h3 className='font-medium mb-2'>Shipping Address</h3>
                        <address className='not-italic text-sm text-muted-foreground'>
                          <p>{orderData.shippingAddress.FullName}</p>
                          <p>{orderData.shippingAddress.Address}</p>
                          <p>
                            {orderData.shippingAddress.City},
                            {orderData.shippingAddress.PostalCode}
                          </p>
                          <p>{orderData.shippingAddress.Country}</p>
                          {orderData.shippingAddress.Phone && (
                            <p>Phone: {orderData.shippingAddress.Phone}</p>
                          )}
                        </address>
                      </div>
                    )}

                    {orderData.billingAddress && (
                      <div>
                        <h3 className='font-medium mb-2'>Billing Address</h3>
                        <address className='not-italic text-sm text-muted-foreground'>
                          <p>{orderData.billingAddress.FullName}</p>
                          <p>{orderData.billingAddress.Address}</p>
                          <p>
                            {orderData.billingAddress.City},
                            {orderData.billingAddress.PostalCode}
                          </p>
                          <p>{orderData.billingAddress.Country}</p>
                          {orderData.billingAddress.Phone && (
                            <p>Phone: {orderData.billingAddress.Phone}</p>
                          )}
                        </address>
                      </div>
                    )}
                  </div>
                </CardContent>
              </Card>
            )}

          {/* Order Details */}
          {/* products: Array<{
    id: number;
    name: string;
    quantity: number;
    price: number;
    total: number;
  }>; */}
          {orderData && (
            <Card className='mb-8'>
              <CardHeader>
                <CardTitle>Order Details</CardTitle>
              </CardHeader>
              <CardContent>
                <div className='space-y-4'>
                  {orderData.products && orderData.products.length > 0 ? (
                    orderData.products.map((item, index) => (
                      <div
                        key={index}
                        className='flex justify-between items-start'
                      >
                        <div>
                          <h4 className='font-medium'>{item.title}</h4>
                        </div>
                        <div className='text-right'>
                          <p className='font-medium'>
                            ₹{item.price.toFixed(2)}
                          </p>
                        </div>
                      </div>
                    ))
                  ) : (
                    <div className='text-muted-foreground'>
                      No product details available
                    </div>
                  )}

                  <Separator />
                  <div className='space-y-2'>
                    {orderData.amount !== undefined && (
                      <div className='flex justify-between text-sm'>
                        <span className='text-muted-foreground'>Amount:</span>
                        <span>₹{orderData.amount.toFixed(2)}</span>
                      </div>
                    )}
                    {orderData.coupon && (
                      <div className='flex justify-between text-sm'>
                        <span className='text-muted-foreground'>
                          Coupon Applied:
                        </span>
                        <span className='text-green-600'>
                          {orderData.coupon}
                        </span>
                      </div>
                    )}
                    {orderData.paymentInfo?.PAYMENTMODE && (
                      <div className='flex justify-between text-sm'>
                        <span className='text-muted-foreground'>
                          Payment method:
                        </span>
                        <span>{orderData.paymentInfo.PAYMENTMODE}</span>
                      </div>
                    )}
                    {orderData.transactionid && (
                      <div className='flex justify-between text-sm'>
                        <span className='text-muted-foreground'>
                          Transaction ID:
                        </span>
                        <span className='text-xs md:text-sm font-mono'>
                          {orderData.transactionid}
                        </span>
                      </div>
                    )}

                    <Separator />

                    {orderData.amount !== undefined && (
                      <div className='flex justify-between font-medium'>
                        <span>Total:</span>
                        <span>₹{orderData.amount.toFixed(2)}</span>
                      </div>
                    )}
                  </div>
                </div>
              </CardContent>
            </Card>
          )}
        </>
      ) : (
        <Card className='mb-8'>
          <CardContent className='pt-6'>
            <div className='text-center py-8'>
              <p className='text-lg mb-6'>
                Please make an order to view order details.
              </p>
              <p className='text-muted-foreground mb-6'>
                No order information was found. You may need to complete a
                purchase first.
              </p>
            </div>
          </CardContent>
        </Card>
      )}

      {/* Continue Shopping Button */}
      <div className='text-center'>
        <Button asChild size='lg'>
          <Link href='/products'>Continue Shopping</Link>
        </Button>
      </div>
    </div>
  );
}
