import { type NextRequest, NextResponse } from 'next/server';
export const dynamic = 'force-dynamic';

export async function GET(request: NextRequest) {
  try {
    // Get query parameters from the request
    const searchParams = request.nextUrl.searchParams;
    const vehiclemodel = searchParams.get('vehiclemodel');
    const wheelPos = searchParams.get('wheelPos');
    const tyreType = searchParams.get('tyreType');
    const sort = searchParams.get('sort');

    // Validate required parameters
    if (!vehiclemodel) {
      return NextResponse.json(
        { error: 'Vehicle model is required' },
        { status: 400 }
      );
    }

    // Build the API URL with filters
    let apiUrl = `https://tyrefinder.co.in/api/products?populate=*&filters[vehicle_models][slug][$eq]=${vehiclemodel}`;

    // Add wheel position filter if provided
    if (wheelPos) {
      apiUrl += `&filters[WheelPosition][$eq]=${wheelPos}`;
    }

    // Add tyre type filter if provided
    if (tyreType === 'Tubeless') {
      apiUrl += `&filters[product_attributes][attributename][$containsi]=Tubing Tubeless`;
    } else if (tyreType === 'Tubular') {
      apiUrl += `&filters[product_attributes][attributename][$containsi]=Tubing Tubular`;
    }

    // Add sorting if provided
    if (sort === 'asc') {
      apiUrl += '&sort[0]=price:asc';
    } else if (sort === 'desc') {
      apiUrl += '&sort[0]=price:desc';
    }

    // Fetch data from the external API
    const response = await fetch(apiUrl);

    if (!response.ok) {
      return NextResponse.json(
        { error: `Failed to fetch data: ${response.statusText}` },
        { status: response.status }
      );
    }

    const data = await response.json();

    // Process the data to match the expected format for the frontend
    const processedProducts = data.data.map((item: any) => ({
      id: item.id,
      title: item.attributes.title,
      price: item.attributes.price,
      regularPrice: item.attributes.regularPrice,
      salePrice: item.attributes.salePrice,
      slug: item.attributes.slug,
      sku: item.attributes.sku,
      shortdescription: item.attributes.shortdescription,
      content: item.attributes.content,
      wheelPosition: item.attributes.WheelPosition,
      stockStatus: item.attributes.stockStatus,
      product_subcategory: item.attributes.product_subcategory,
      product_attributes: item.attributes.product_attributes,
      // Handle image URLs - they need the base URL
      images: item.attributes.images.data.map((img: any) => ({
        id: img.id,
        url: `https://tyrefinder.co.in${img.attributes.url}`,
        alt: img.attributes.alternativeText || item.attributes.title,
        // Include thumbnail for responsive images
        thumbnail: img.attributes.formats.thumbnail
          ? `https://tyrefinder.co.in${img.attributes.formats.thumbnail.url}`
          : `https://tyrefinder.co.in${img.attributes.url}`,
      })),
    }));

    // Return the processed data
    return NextResponse.json({
      products: processedProducts,
      meta: data.meta,
    });
  } catch (error) {
    console.error('API route error:', error);
    return NextResponse.json(
      { error: 'Internal server error' },
      { status: 500 }
    );
  }
}
