import Image from 'next/image';
import Link from 'next/link';
import {
  Card,
  CardContent,
  CardDescription,
  CardFooter,
  CardHeader,
  CardTitle,
} from '@/components/ui/card';
import { Skeleton } from '@/components/ui/skeleton';
// import { formatDistanceToNow } from 'date-fns';

// Helper function to strip HTML tags and get a preview
function getTextPreview(html: string, maxLength = 150): string {
  // Remove HTML tags
  const text = html
    .replace(/<[^>]*>/g, ' ')
    .replace(/\s+/g, ' ')
    .trim();
  // Return a preview
  return text.length > maxLength ? text.substring(0, maxLength) + '...' : text;
}

// Define types for the blog data based on the actual API response
interface FeaturedImage {
  data: {
    id: number;
    attributes: {
      name: string;
      width: number;
      height: number;
      formats: {
        thumbnail: { url: string };
        small: { url: string };
        medium: { url: string };
        large: { url: string };
      };
      url: string;
    };
  };
}

interface BlogCategory {
  data: {
    id: number;
    attributes: {
      Categoryname: string;
      slug: string;
    };
  };
}

interface BlogAttributes {
  Headline: string;
  Slug: string;
  RichText: string;
  createdAt: string;
  updatedAt: string;
  publishedAt: string;
  publisheddate: string;
  FeaturedImage: FeaturedImage;
  blog_category: BlogCategory;
}

interface BlogItem {
  id: number;
  attributes: BlogAttributes;
}

interface BlogResponse {
  data: BlogItem[];
  meta: {
    pagination: {
      page: number;
      pageSize: number;
      pageCount: number;
      total: number;
    };
  };
}

async function getNewsBlogs(): Promise<BlogResponse> {
  // Use relative URL in production, absolute URL in development
  const baseUrl = process.env.NEXT_PUBLIC_PROD_API_URL;

  const res = await fetch(`${baseUrl}/api/v1/blog/in-the-news`, {
    cache: 'no-store',
  });

  if (!res.ok) {
    const error = { message: 'Failed to fetch blog data' };
    throw error;
  }

  return res.json();
}

export default async function InTheNewsPage() {
  const blogs = await getNewsBlogs();

  return (
    <>
      <div className='bg-tegblue w-full py-[50px]'>
        <div className='container mx-auto px-4 py-8'>
          <h1 className='text-[35px] font-bold mb-0 uppercase text-center text-white'>
            In the news
          </h1>
        </div>
      </div>
      <div className='container mx-auto py-12 px-4'>
        {blogs.data.length === 0 ? (
          <p className='text-center text-muted-foreground py-12'>
            No news articles found.
          </p>
        ) : (
          <div className='grid grid-cols-1 md:grid-cols-2 lg:grid-cols-4 gap-6'>
            {blogs.data.map((blog) => (
              <Card key={blog.id} className='overflow-hidden bg-gray-100'>
                <div className='relative h-48 w-full'>
                  {blog.attributes.FeaturedImage?.data ? (
                    <Image
                      src={`https://tyrefinder.co.in${blog.attributes.FeaturedImage.data.attributes.url}`}
                      alt={blog.attributes.Headline}
                      fill
                      className='object-cover'
                    />
                  ) : (
                    <div className='h-full w-full bg-muted flex items-center justify-center'>
                      <p className='text-muted-foreground'>No image</p>
                    </div>
                  )}
                </div>
                <CardHeader>
                  <CardTitle className='line-clamp-2'>
                    <Link
                      href={`/blog/${blog?.attributes?.blog_category?.data?.attributes?.slug}/${blog.attributes.Slug}'`}
                    >
                      {blog.attributes.Headline}
                    </Link>
                  </CardTitle>
                </CardHeader>
                <CardContent>
                  <p className='line-clamp-3 text-muted-foreground'>
                    {blog.attributes.RichText
                      ? blog.attributes.RichText.replace(
                          /<[^>]*>/g,
                          ''
                        ).substring(0, 150) + '...'
                      : 'No content available'}
                  </p>
                </CardContent>
                <CardFooter className='flex justify-between'>
                  <div className='text-sm text-muted-foreground'>
                    {new Date(
                      blog.attributes.publisheddate ||
                        blog.attributes.publishedAt
                    ).toLocaleDateString()}
                  </div>
                  <div className='flex gap-2'>
                    {blog.attributes.blog_category?.data && (
                      <Link
                        href={`/blog/${blog.attributes.blog_category.data.attributes.slug}`}
                        className='text-xs bg-primary/10 text-primary px-2 py-1 rounded-full hover:bg-primary/20 transition-colors'
                      >
                        {
                          blog.attributes.blog_category.data.attributes
                            .Categoryname
                        }
                      </Link>
                    )}
                  </div>
                </CardFooter>
              </Card>
            ))}
          </div>
        )}
      </div>
    </>
  );
}
