'use client';

import { useEffect } from 'react';
import Image from 'next/image';
import Link from 'next/link';
import {
  Card,
  CardContent,
  CardFooter,
  CardHeader,
  CardTitle,
} from '@/components/ui/card';
import { useBlogStore } from '@/store/useBlogStore';
import { Skeleton } from '@/components/ui/skeleton';

export default function BlogGrid({ col }: { col?: number }) {
  const { blogs, isLoading, fetchBlogs } = useBlogStore();

  useEffect(() => {
    fetchBlogs();
  }, [fetchBlogs]);

  if (isLoading) {
    return (
      <div
        className={`grid grid-cols-1 md:grid-cols-2 ${
          col ? 'lg:grid-cols-' + col : 'lg:grid-cols-3'
        } gap-6`}
      >
        {Array(6)
          .fill(0)
          .map((_, i) => (
            <Skeleton key={i} className='h-[300px] w-full rounded-md' />
          ))}
      </div>
    );
  }

  if (blogs.length === 0) {
    return (
      <div className='flex justify-center items-center h-64'>
        <p className='text-lg text-muted-foreground'>No blog posts found</p>
      </div>
    );
  }

  return (
    <div
      className={`grid grid-cols-1 md:grid-cols-2 ${
        col ? 'lg:grid-cols-' + col : 'lg:grid-cols-3'
      } gap-6`}
    >
      {blogs.map((blog) => (
        <Card key={blog.id} className='overflow-hidden bg-gray-100'>
          <div className='relative h-48 w-full'>
            {blog.attributes.FeaturedImage?.data ? (
              <Image
                src={`https://tyrefinder.co.in${blog.attributes.FeaturedImage.data.attributes.url}`}
                alt={blog.attributes.Headline}
                fill
                className='object-cover'
              />
            ) : (
              <div className='h-full w-full bg-muted flex items-center justify-center'>
                <p className='text-muted-foreground'>No image</p>
              </div>
            )}
          </div>
          <CardHeader>
            <CardTitle className='line-clamp-2'>
              <Link
                href={`/blog/${blog?.attributes?.blog_category?.data?.attributes?.slug}/${blog.attributes.Slug}'`}
              >
                {blog.attributes.Headline}
              </Link>
            </CardTitle>
          </CardHeader>
          <CardContent>
            <p className='line-clamp-3 text-muted-foreground'>
              {blog.attributes.RichText
                ? blog.attributes.RichText.replace(/<[^>]*>/g, '').substring(
                    0,
                    150
                  ) + '...'
                : 'No content available'}
            </p>
          </CardContent>
          <CardFooter className='flex justify-between'>
            <div className='text-sm text-muted-foreground'>
              {new Date(
                blog.attributes.publisheddate || blog.attributes.publishedAt
              ).toLocaleDateString()}
            </div>
            <div className='flex gap-2'>
              {blog.attributes.blog_category?.data && (
                <Link
                  href={`/blog/${blog.attributes.blog_category.data.attributes.slug}`}
                  className='text-xs bg-primary/10 text-primary px-2 py-1 rounded-full hover:bg-primary/20 transition-colors'
                >
                  {blog.attributes.blog_category.data.attributes.Categoryname}
                </Link>
              )}
              {blog.attributes.blog_subcategory?.data && (
                <Link
                  href={`/blog/${
                    blog.attributes.blog_subcategory.data.attributes &&
                    blog.attributes.blog_subcategory.data.attributes.slug
                  }`}
                  className='text-xs bg-secondary/10 text-secondary px-2 py-1 rounded-full hover:bg-secondary/20 transition-colors'
                >
                  {blog.attributes.blog_subcategory.data.attributes &&
                    blog.attributes.blog_subcategory.data.attributes.name}
                </Link>
              )}
            </div>
          </CardFooter>
        </Card>
      ))}
    </div>
  );
}
