'use client';
import { useEffect, useState } from 'react';
import Link from 'next/link';
import BoxContainer from '../box-container';
import BlogCard from './BlogCard';
import Image from 'next/image';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
import { IconDefinition } from '@fortawesome/free-solid-svg-icons';
import { formatDate } from '@/lib/utils';

export default function BlogSection({
  title,
  categories = 'default-category', // Default category to prevent undefined
  icon,
}: {
  title: string;
  categories?: string;
  icon?: IconDefinition;
}) {
  const [blogPosts, setBlogPosts] = useState<BlogPost[]>([]);
  const [loading, setLoading] = useState(true);
  const [error, setError] = useState<string | null>(null);

  useEffect(() => {
    const fetchData = async () => {
      try {
        const response = await fetch(
          `https://tyrefinder.co.in/api/blogs?populate=*&filters[blog_category][slug][$eq]=${categories}&pagination[pageSize]=8`
        );
        if (!response.ok) {
          throw new Error('Data could not be fetched!');
        }
        const data: ApiResponse = await response.json();
        setBlogPosts(data.data);
      } catch (error) {
        setError((error as Error).message);
      } finally {
        setLoading(false);
      }
    };

    fetchData();
  }, [categories]);

  if (loading) return <div>Loading...</div>;
  if (error) return <div>Error: {error}</div>;

  return (
    <div className='py-[100px]'>
      <BoxContainer>
        <div className='flex justify-center items-center mb-8 gap-3'>
          {!icon && (
            <Image
              src={'/assets/icons/news-n-events-icons.png'}
              width={40}
              height={40}
              alt=''
            />
          )}
          {icon && (
            <FontAwesomeIcon
              icon={icon}
              className='bg-tegred p-3 rounded-full text-white'
            />
          )}
          <h2 className='text-[25px] text-[#295CA9] font-bold text-center'>
            {title}
          </h2>
        </div>
        <div className='grid grid-cols-1 sm:grid-cols-2 lg:grid-cols-4 gap-6'>
          {blogPosts.map((post) => {
            return (
              <BlogCard
                key={post.id}
                thumbnail={`https://tyrefinder.co.in${post.attributes.FeaturedImage.data.attributes.formats.thumbnail.url}`}
                title={post.attributes.Headline}
                description={post.attributes.RichText}
                readMoreLink={`/blog/${categories}/${post.attributes.Slug}`}
                date={formatDate(post.attributes.publisheddate, 'date')}
                commentCount={0} // Assuming comments are not part of the response
              />
            );
          })}
        </div>
        {/* <div className='w-full flex justify-center mt-6'>
          <Link
            href={'#'}
            className='inline-block bg-blue-500 text-white px-4 py-2 rounded hover:bg-blue-600 transition-colors'
          >
            Read More
          </Link>
        </div> */}
      </BoxContainer>
    </div>
  );
}
