// src/components/ClientProductList.tsx

'use client';

import { useState, useEffect } from 'react';
import { useProductStore } from '@/store/useProductStore';

import ProductCard from '@/components/shared/product/product-card';
import { ProductProps } from '@/type/strapi-products';
import FilterTags from '@/components/shared/product/filter/filter-tags';

const ITEMS_PER_PAGE = 6;

export default function ClientProductList() {
  const {
    brand,
    model,
    wheelPosition,
    priceRange,
    frontTyreSize,
    rearTyreSize,
    pattern,
    segment,
  } = useProductStore();
  const [products, setProducts] = useState<ProductProps[]>([]);
  const [loading, setLoading] = useState(true);
  const [error, setError] = useState<string | null>(null);
  const [currentPage, setCurrentPage] = useState(1);
  const [totalPages, setTotalPages] = useState(1);

  useEffect(() => {
    const fetchProducts = async () => {
      setLoading(true);
      setError(null);
      try {
        const params = new URLSearchParams();
        params.append('category', 'two-wheeler');
        if (brand) params.append('brand', brand);
        if (model) params.append('model', model);
        if (wheelPosition) params.append('wheelPosition', wheelPosition);
        if (frontTyreSize) params.append('frontTyreSize', frontTyreSize);
        if (rearTyreSize) params.append('rearTyreSize', rearTyreSize);
        if (pattern) params.append('pattern', pattern);
        if (segment) params.append('segment', segment);
        params.append('page', currentPage.toString());
        params.append('minPrice', priceRange.min.toString());
        params.append('maxPrice', priceRange.max.toString());

        const queryString = params.toString();
        const url = `/api/v1/products${queryString ? `?${queryString}` : ''}`;
        const res = await fetch(url);
        if (!res.ok) {
          throw new Error('Failed to fetch products');
        }
        const data = await res.json();
        setProducts(data.data);
        setTotalPages(Math.ceil(data.meta.pagination.total / ITEMS_PER_PAGE));
      } catch (err) {
        setError('An error occurred while fetching products');
        console.error(err);
      } finally {
        setLoading(false);
      }
    };

    fetchProducts();
  }, [
    brand,
    model,
    wheelPosition,
    currentPage,
    priceRange,
    frontTyreSize,
    rearTyreSize,
    pattern,
    segment,
  ]);

  const handlePageChange = (page: number) => {
    setCurrentPage(page);
  };

  if (loading) {
    return <div className='text-center'>Loading...</div>;
  }

  if (error) {
    return <div className='text-center text-red-500'>{error}</div>;
  }

  if (products.length === 0) {
    return (
      <>
        <FilterTags />
        <p className='text-center text-xl'>No products found.</p>
      </>
    );
  }

  return (
    <div>
      <FilterTags />
      <Pagination
        currentPage={currentPage}
        totalPages={totalPages}
        onPageChange={handlePageChange}
      />
      <div className='grid grid-cols-1 sm:grid-cols-2 md:grid-cols-3 gap-6 mb-8'>
        {products.map((product) => (
          <ProductCard key={product.id} product={product} />
        ))}
      </div>
    </div>
  );
}

interface PaginationProps {
  currentPage: number;
  totalPages: number;
  onPageChange: (page: number) => void;
}

function Pagination({
  currentPage,
  totalPages,
  onPageChange,
}: PaginationProps) {
  const pageNumbers = [];
  for (let i = 1; i <= totalPages; i++) {
    pageNumbers.push(i);
  }

  return (
    <div className='flex justify-center items-center space-x-2'>
      <button
        onClick={() => onPageChange(currentPage - 1)}
        disabled={currentPage === 1}
        className='px-4 py-2 border rounded-md disabled:opacity-50'
      >
        Prev
      </button>
      {pageNumbers.map((number) => (
        <button
          key={number}
          onClick={() => onPageChange(number)}
          className={`px-1 border rounded-md ${
            currentPage === number ? 'bg-blue-500 text-white' : ''
          }`}
        >
          {number}
        </button>
      ))}
      <button
        onClick={() => onPageChange(currentPage + 1)}
        disabled={currentPage === totalPages}
        className='px-4 py-2 border rounded-md disabled:opacity-50'
      >
        Next
      </button>
    </div>
  );
}
