'use client';
import { useState } from 'react';
import Image from 'next/image';
import Link from 'next/link';
import StarRating from '@/components/shared/star-rating';
import { useComparisonStore } from '@/store/useComparisonStore';
import { useCartStore } from '@/store/useCartStore';

const ITEMS_PER_PAGE = 6;

// Updated to handle the new API response structure
const ProductGrid = ({ productList }: { productList: any[] }) => {
  const { addProduct } = useComparisonStore();
  const { addItemCart } = useCartStore();
  const [currentPage, setCurrentPage] = useState(1);

  const totalPages = Math.ceil(productList.length / ITEMS_PER_PAGE);

  const handleNextPage = () => {
    setCurrentPage((prevPage) => Math.min(prevPage + 1, totalPages));
  };

  const handlePreviousPage = () => {
    setCurrentPage((prevPage) => Math.max(prevPage - 1, 1));
  };

  const handlePageClick = (page: number) => {
    setCurrentPage(page);
  };

  const startIndex = (currentPage - 1) * ITEMS_PER_PAGE;
  const currentProducts =
    productList.length > ITEMS_PER_PAGE
      ? productList.slice(startIndex, startIndex + ITEMS_PER_PAGE)
      : productList;

  return (
    <>
      {/* Pagination Controls */}
      {productList.length > ITEMS_PER_PAGE ? (
        <div className='flex justify-center gap-4 mt-5'>
          <button
            onClick={handlePreviousPage}
            disabled={currentPage === 1}
            className='px-2 py-2 bg-gray-200 rounded disabled:opacity-50 text-[14px]'
          >
            Previous
          </button>
          {Array.from({ length: totalPages }, (_, index) => (
            <button
              key={index}
              onClick={() => handlePageClick(index + 1)}
              className={`px-0 py-1 rounded border border-transparent transition-colors duration-200 text-[14px] ${
                currentPage === index + 1
                  ? 'text-blue-500 font-semibold'
                  : 'text-black'
              } hover:border-gray-300 focus:outline-none`}
            >
              {index + 1}
            </button>
          ))}
          <button
            onClick={handleNextPage}
            disabled={currentPage === totalPages}
            className='px-4 py-2 bg-gray-200 rounded disabled:opacity-50 text-[14px]'
          >
            Next
          </button>
        </div>
      ) : (
        ''
      )}
      <div className='flex gap-[15px] flex-wrap'>
        {currentProducts.map((product) => {
          // Get the first two images for the hover effect
          const primaryImage =
            product.images && product.images.length > 0
              ? product.images[0].url
              : '/placeholder.svg';

          const secondaryImage =
            product.images && product.images.length > 1
              ? product.images[1].url
              : primaryImage;

          // Get product category and wheel position
          const category =
            product.product_subcategory?.data?.attributes?.name || 'Tyre';
          const wheelPosition = product.wheelPosition || '';

          // Get the slug for the product detail page
          const slug = product.slug || '';

          return (
            <div
              key={product.id}
              className='w-[257px] h-auto group cursor-pointer text-center card-shadow'
            >
              <div className='overflow-hidden w-full h-[257px] relative'>
                <button
                  className='bg-[#c5c6c6] mt-3 text-tegblue px-3 py-2 hidden group-hover:block posZ hover:bg-tegred hover:text-white'
                  onClick={() => addProduct(product)}
                >
                  Add to compare
                </button>
                <div className='absolute mt-3 inset-0 transition-transform duration-500 ease-in-out group-hover:-translate-x-full'>
                  <Image
                    src={primaryImage || '/placeholder.svg'}
                    width={257}
                    height={257}
                    alt={product.title || 'Product image'}
                    style={{
                      width: '100%',
                      height: '100%',
                      objectFit: 'contain',
                    }}
                  />
                </div>
                <div className='absolute inset-0 mt-3 transition-transform duration-500 ease-in-out translate-x-full group-hover:translate-x-0'>
                  <Image
                    src={secondaryImage || '/placeholder.svg'}
                    width={257}
                    height={257}
                    alt={product.title || 'Product image'}
                    style={{
                      width: '100%',
                      height: '100%',
                      objectFit: 'contain',
                    }}
                  />
                </div>
              </div>
              <div className='p-3 text-[14px]'>
                <span className='text-tegblue block'>{category}</span>
                <span className='text-tegblue mb-3 block'>{wheelPosition}</span>
                <Link href={'/product/' + slug}>
                  <h3 className='text-tegred font-bold underline uppercase mb-1'>
                    {product.title}
                  </h3>
                </Link>
                <div className='flex justify-center mb-1'>
                  <StarRating value={100} />
                </div>
                <span className='text-tegred text-[20px] font-bold block mb-3'>
                  ₹{product.price}
                </span>
                <div className='w-full flex gap-x-2 justify-center'>
                  <Link
                    href={'/product/' + slug}
                    className='bg-tegblue hover:bg-tegblue text-white px-3 py-2 rounded-sm'
                  >
                    View Product
                  </Link>
                  <button
                    className='bg-tegred hover:bg-tegblue text-white px-3 py-2'
                    onClick={() => {
                      addItemCart({
                        id: product.id,
                        title: product.title,
                        price: product.price,
                        sku: product.sku || '',
                        permalink: `/product/${slug}`,
                        image: product?.images[0].url,
                      });
                    }}
                  >
                    Add to cart
                  </button>
                </div>
              </div>
            </div>
          );
        })}
      </div>
    </>
  );
};

export default ProductGrid;
