'use client';

import type React from 'react';
import { useState, useEffect } from 'react';
import { useProductStore } from '@/store/useProductStore';
import { useRouter } from 'next/navigation';
import {
  brandsList,
  modelsList,
  wheelPosList,
} from '@/constants/hierearchical-filter-data';

interface HierarchicalFilterProps {
  disableTyrePos?: boolean;
  showRedirectBtn?: boolean;
}

export default function HierarchicalFilter({
  disableTyrePos = false,
  showRedirectBtn = false,
}: HierarchicalFilterProps) {
  const { setBrand, setModel, setWheelPosition, brand, model } =
    useProductStore();
  const [selectedBrand, setSelectedBrand] = useState(brand || '');
  const [selectedModel, setSelectedModel] = useState(model || '');
  const [filteredModels, setFilteredModels] = useState(modelsList);
  const router = useRouter();

  // Sync local state with store state
  useEffect(() => {
    setSelectedBrand(brand);

    // Only update filtered models if brand exists
    if (brand) {
      const filtered = modelsList.filter(
        (modelItem) => modelItem.brandslug === brand
      );
      setFilteredModels(filtered);
    } else {
      setFilteredModels([]);
    }
  }, [brand]);

  // Sync model local state with store state
  useEffect(() => {
    setSelectedModel(model);
  }, [model]);

  // Update filtered models when brand changes
  useEffect(() => {
    if (selectedBrand) {
      const filtered = modelsList.filter(
        (modelItem) => modelItem.brandslug === selectedBrand
      );
      setFilteredModels(filtered);
    } else {
      setFilteredModels([]);
    }
  }, [selectedBrand]);

  const handleBrandChange = (e: React.ChangeEvent<HTMLSelectElement>) => {
    const brandSlug = e.target.value;
    setSelectedBrand(brandSlug);
    setBrand(brandSlug);

    // Reset model when brand changes
    setSelectedModel('');
    setModel('');
    setWheelPosition('');
  };

  const handleModelChange = (e: React.ChangeEvent<HTMLSelectElement>) => {
    const modelSlug = e.target.value;
    setSelectedModel(modelSlug);
    setModel(modelSlug);
  };

  const handleWheelPositionChange = (
    e: React.ChangeEvent<HTMLSelectElement>
  ) => {
    setWheelPosition(e.target.value);
  };

  const handleRedirect = () => {
    // Ensure brand and model are set in the store before redirecting
    if (selectedBrand) setBrand(selectedBrand);
    if (selectedModel) setModel(selectedModel);

    router.push('/product-category/two-wheeler');
  };

  return (
    <div className='flex flex-col gap-4'>
      <select
        value={selectedBrand}
        onChange={handleBrandChange}
        className='w-full border border-gray-300 rounded-md p-2 text-gray-700 bg-white focus:outline-none focus:border-[#E31837] focus:ring-1 focus:ring-[#E31837] transition-colors'
      >
        <option value=''>Select Brand</option>
        {brandsList.map((brandItem) => (
          <option key={brandItem.id} value={brandItem.brandslug}>
            {brandItem.brand}
          </option>
        ))}
      </select>
      <select
        value={selectedModel}
        onChange={handleModelChange}
        className='w-full border border-gray-300 rounded-md p-2 text-gray-700 bg-white focus:outline-none focus:border-[#E31837] focus:ring-1 focus:ring-[#E31837] transition-colors'
        disabled={!selectedBrand}
      >
        <option value=''>Select Model</option>
        {filteredModels.map((modelItem) => (
          <option key={modelItem.id} value={modelItem.modelslug}>
            {modelItem.model}
          </option>
        ))}
      </select>
      {!disableTyrePos && (
        <select
          onChange={handleWheelPositionChange}
          className='w-full border border-gray-300 rounded-md p-2 text-gray-700 bg-white focus:outline-none focus:border-[#E31837] focus:ring-1 focus:ring-[#E31837] transition-colors'
          disabled={!selectedModel}
        >
          <option value=''>Select Wheel Position</option>
          {wheelPosList.map((position) => (
            <option key={position} value={position}>
              {position}
            </option>
          ))}
        </select>
      )}
      {showRedirectBtn && (
        <button
          onClick={handleRedirect}
          disabled={!selectedBrand || !selectedModel}
          className='w-full py-2 px-4 rounded font-semibold text-white transition-colors bg-[#E31837] hover:bg-[#c01530] disabled:bg-gray-400 disabled:cursor-not-allowed'
        >
          FIND TYRES
        </button>
      )}
    </div>
  );
}
