// src/components/FilterTags.tsx
'use client';

import { useProductStore } from '@/store/useProductStore';
import { X } from 'lucide-react';
import { frontTyreSizeList, rearTyreSizeList } from '@/constants/tyresize';
import { patternList } from '@/constants/pattern';
import { segmentList } from '@/constants/segments';

export default function FilterTags() {
  const {
    brand,
    setBrand,
    model,
    setModel,
    wheelPosition,
    setWheelPosition,
    priceRange,
    setPriceRange,
    frontTyreSize,
    setFrontTyreSize,
    rearTyreSize,
    setRearTyreSize,
    pattern,
    setPattern,
    segment,
    setSegment,
    setSelect,
  } = useProductStore();

  // Helper function to get display name from slug
  const getFrontTyreSizeName = (slug: string) => {
    const size = frontTyreSizeList.find(
      (item) => item.attributes.slug === slug
    );
    return size?.attributes.size || slug;
  };

  const getRearTyreSizeName = (slug: string) => {
    const size = rearTyreSizeList.find((item) => item.attributes.slug === slug);
    return size?.attributes.size || slug;
  };

  const getPatternName = (slug: string) => {
    const patternItem = patternList.find(
      (item) => item.attributes.slug === slug
    );
    return patternItem?.attributes.name || slug;
  };

  const getSegmentName = (slug: string) => {
    const segmentItem = segmentList.find(
      (item) => item.attributes.slug === slug
    );
    return segmentItem?.attributes.name || slug;
  };

  // Function to clear all filters
  const clearAllFilters = () => {
    setBrand('');
    setModel('');
    setWheelPosition('');
    setPriceRange({ min: 0, max: 10000 });
    setFrontTyreSize('');
    setRearTyreSize('');
    setPattern('');
    setSegment('');
    setSelect('');
  };

  // Check if any filters are active
  const hasActiveFilters =
    brand ||
    model ||
    wheelPosition ||
    frontTyreSize ||
    rearTyreSize ||
    pattern ||
    segment ||
    priceRange.min !== 0 ||
    priceRange.max !== 10000;

  // If no filters are active, don't render anything
  if (!hasActiveFilters) {
    return null;
  }

  // Create an array of active filters
  const activeFilters = [
    brand && { label: `Brand: ${brand}`, onRemove: () => setBrand('') },
    model && { label: `Model: ${model}`, onRemove: () => setModel('') },
    wheelPosition && {
      label: `Position: ${wheelPosition}`,
      onRemove: () => setWheelPosition(''),
    },
    (priceRange.min !== 0 || priceRange.max !== 10000) && {
      label: `Price: ₹${priceRange.min} - ₹${priceRange.max}`,
      onRemove: () => setPriceRange({ min: 0, max: 10000 }),
    },
    frontTyreSize && {
      label: `Front Size: ${getFrontTyreSizeName(frontTyreSize)}`,
      onRemove: () => setFrontTyreSize(''),
    },
    rearTyreSize && {
      label: `Rear Size: ${getRearTyreSizeName(rearTyreSize)}`,
      onRemove: () => setRearTyreSize(''),
    },
    pattern && {
      label: `Pattern: ${getPatternName(pattern)}`,
      onRemove: () => setPattern(''),
    },
    segment && {
      label: `Segment: ${getSegmentName(segment)}`,
      onRemove: () => setSegment(''),
    },
  ].filter(Boolean); // Remove falsy values

  return (
    <div className='flex flex-wrap gap-2 mb-4 items-center'>
      {/* Active Filter Tags */}
      {activeFilters.map(
        (filter, index) =>
          filter && (
            <Tag key={index} label={filter.label} onRemove={filter.onRemove} />
          )
      )}

      {/* Clear All Button - Only shown when there are active filters */}
      {hasActiveFilters && (
        <button
          onClick={clearAllFilters}
          className='ml-2 px-3 py-1 text-sm font-medium text-red-600 hover:text-red-800 hover:underline'
        >
          Clear All
        </button>
      )}
    </div>
  );
}

// Tag subcomponent
function Tag({ label, onRemove }: { label: string; onRemove: () => void }) {
  return (
    <div className='inline-flex items-center gap-1 bg-gray-100 text-gray-800 px-3 py-1 rounded-full text-sm'>
      <span>{label}</span>
      <button
        onClick={onRemove}
        className='hover:bg-gray-200 rounded-full p-0.5'
        aria-label={`Remove ${label} filter`}
      >
        <X className='w-3 h-3' />
      </button>
    </div>
  );
}
