"use client";

import { useState } from "react";
import Image from "next/image";
import { Play } from "lucide-react";
import { Dialog, DialogContent } from "@/components/ui/dialog";

type Video = {
  id: string;
  title: string;
  youtubeId: string;
};

export default function VideoGallery({ videos }: { videos: Video[] }) {
  const [selectedVideo, setSelectedVideo] = useState<Video | null>(null);
  const [isOpen, setIsOpen] = useState(false);
  const [thumbnailErrors, setThumbnailErrors] = useState<
    Record<string, boolean>
  >({});

  const handleVideoClick = (video: Video) => {
    setSelectedVideo(video);
    setIsOpen(true);
  };

  const handleClose = () => {
    setIsOpen(false);
    // Reset the video when dialog closes to stop playback
    setTimeout(() => {
      setSelectedVideo(null);
    }, 300);
  };

  const handleImageError = (videoId: string) => {
    setThumbnailErrors((prev) => ({
      ...prev,
      [videoId]: true,
    }));
  };

  const getThumbnailUrl = (videoId: string) => {
    // Use hqdefault.jpg which is more reliable and available for all videos
    return `https://img.youtube.com/vi/${videoId}/hqdefault.jpg`;
  };

  return (
    <div className="grid grid-cols-1 sm:grid-cols-2 md:grid-cols-3 lg:grid-cols-5 gap-4 px-3 mb-4">
      {videos.map((video) => (
        <div key={video.id} className="relative">
          <div
            className="relative aspect-video overflow-hidden cursor-pointer group"
            onClick={() => handleVideoClick(video)}
          >
            <div className="absolute inset-0 bg-gray-200">
              <Image
                src={getThumbnailUrl(video.youtubeId) || "/placeholder.svg"}
                alt={video.title}
                fill
                sizes="(max-width: 640px) 100vw, (max-width: 768px) 50vw, (max-width: 1024px) 33.3vw, 20vw"
                className="object-cover"
                onError={() => handleImageError(video.id)}
              />
            </div>
            <div className="absolute inset-0 bg-black/20 flex items-center justify-center">
              <div className="bg-black/50 rounded-full p-3 transform transition-transform duration-300 group-hover:scale-110">
                <Play className="h-6 w-6 text-white fill-white" />
                <span className="sr-only">Play Video</span>
              </div>
            </div>
          </div>
        </div>
      ))}

      <Dialog open={isOpen} onOpenChange={handleClose}>
        <DialogContent className="max-w-4xl p-0 bg-black overflow-hidden">
          {selectedVideo && (
            <div className="aspect-video w-full">
              <iframe
                src={`https://www.youtube.com/embed/${selectedVideo.youtubeId}?autoplay=1&rel=0&modestbranding=1`}
                title={selectedVideo.title}
                allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture"
                allowFullScreen
                className="w-full h-full"
              />
            </div>
          )}
        </DialogContent>
      </Dialog>
    </div>
  );
}
