'use client';

import { useState } from 'react';
import Link from 'next/link';
import {
  AlertCircle,
  RefreshCw,
  Home,
  ChevronDown,
  ChevronUp,
  ArrowLeft,
} from 'lucide-react';
import { Button } from '@/components/ui/button';
import { Alert, AlertDescription, AlertTitle } from '@/components/ui/alert';
import { motion, AnimatePresence } from 'framer-motion';

interface ErrorDisplayProps {
  title?: string;
  message?: string;
  error?: Error | unknown;
  retry?: () => void;
  backUrl?: string;
  backLabel?: string;
  homeUrl?: string;
  homeLabel?: string;
  statusCode?: number;
}

// Function to get description for common HTTP status codes
function getStatusCodeDescription(statusCode: number): string {
  const statusDescriptions: Record<number, string> = {
    400: 'Bad Request - The server cannot process the request due to a client error',
    401: 'Unauthorized - Authentication is required and has failed or not been provided',
    403: 'Forbidden - The server understood the request but refuses to authorize it',
    404: 'Not Found - The requested resource could not be found',
    408: 'Request Timeout - The server timed out waiting for the request',
    409: 'Conflict - The request conflicts with the current state of the server',
    422: 'Unprocessable Entity - The request was well-formed but unable to be followed',
    429: 'Too Many Requests - The user has sent too many requests in a given amount of time',
    500: 'Internal Server Error - The server has encountered a situation it does not know how to handle',
    502: 'Bad Gateway - The server received an invalid response from an upstream server',
    503: 'Service Unavailable - The server is not ready to handle the request',
    504: 'Gateway Timeout - The server acting as a gateway timed out waiting for a response',
  };

  return statusDescriptions[statusCode] || 'Unknown Status Code';
}

export function ErrorDisplay({
  title = 'Something went wrong',
  message = 'We encountered an error while processing your request.',
  error,
  retry,
  backUrl,
  backLabel = 'Go Back',
  homeUrl = '/',
  homeLabel = 'Home',
  statusCode,
}: ErrorDisplayProps) {
  const [showDetails, setShowDetails] = useState(false);

  // Extract error message if it's an Error object
  const errorMessage =
    error instanceof Error
      ? error.message
      : error
      ? String(error)
      : 'Unknown error';

  // Extract stack trace if available
  const errorStack = error instanceof Error ? error.stack : null;

  return (
    <div className='flex flex-col items-center justify-center min-h-[50vh] p-6 text-center'>
      <div className='w-full max-w-md'>
        <Alert variant='destructive' className='mb-6'>
          <AlertCircle className='h-5 w-5 mr-2' />
          <AlertTitle className='text-xl font-semibold mb-2'>
            {title}
          </AlertTitle>
          <AlertDescription className='text-base'>{message}</AlertDescription>
        </Alert>

        {statusCode && (
          <div className='mb-6 p-4 bg-muted rounded-md text-center'>
            <div className='inline-flex items-center justify-center w-12 h-12 rounded-full bg-muted-foreground/20 mb-2'>
              <span className='text-lg font-bold'>{statusCode}</span>
            </div>
            <p className='text-sm font-medium'>
              {getStatusCodeDescription(statusCode)}
            </p>
          </div>
        )}

        <div className='flex flex-wrap gap-3 justify-center mb-6'>
          {retry && (
            <Button
              variant='outline'
              onClick={retry}
              className='flex items-center gap-2'
            >
              <RefreshCw className='h-4 w-4' />
              Try Again
            </Button>
          )}

          {backUrl && (
            <Button
              variant='outline'
              asChild
              className='flex items-center gap-2'
            >
              <Link href={backUrl}>
                <ArrowLeft className='h-4 w-4' />
                {backLabel}
              </Link>
            </Button>
          )}

          <Button variant='default' asChild className='flex items-center gap-2'>
            <Link href={homeUrl}>
              <Home className='h-4 w-4' />
              {homeLabel}
            </Link>
          </Button>
        </div>

        {error !== undefined && error !== null && (
          <div className='w-full'>
            <Button
              variant='ghost'
              onClick={() => setShowDetails(!showDetails)}
              className='flex items-center justify-center gap-2 w-full mb-2 text-muted-foreground'
            >
              {showDetails ? (
                <>
                  <ChevronUp className='h-4 w-4' />
                  Hide Technical Details
                </>
              ) : (
                <>
                  <ChevronDown className='h-4 w-4' />
                  Show Technical Details
                </>
              )}
            </Button>

            <AnimatePresence>
              {showDetails && (
                <motion.div
                  initial={{ height: 0, opacity: 0 }}
                  animate={{ height: 'auto', opacity: 1 }}
                  exit={{ height: 0, opacity: 0 }}
                  transition={{ duration: 0.3 }}
                  className='overflow-hidden'
                >
                  <div className='bg-muted p-4 rounded-md text-left overflow-auto max-h-[300px] text-sm'>
                    <p className='font-semibold mb-2'>Error Message:</p>
                    <p className='mb-4 text-red-500'>{errorMessage}</p>

                    {errorStack && (
                      <>
                        <p className='font-semibold mb-2'>Stack Trace:</p>
                        <pre className='whitespace-pre-wrap text-xs text-muted-foreground'>
                          {errorStack}
                        </pre>
                      </>
                    )}
                  </div>
                </motion.div>
              )}
            </AnimatePresence>
          </div>
        )}
      </div>
    </div>
  );
}
