"use client";
// eslint-disable-next-line react-hooks/exhaustive-deps

import { useEffect, useRef, useState } from "react";
import Image from "next/image";
import { FontAwesomeIcon } from "@fortawesome/react-fontawesome";
import { IconName, IconPrefix, library } from "@fortawesome/fontawesome-svg-core";
import { fas } from "@fortawesome/free-solid-svg-icons";
import { far } from "@fortawesome/free-regular-svg-icons";
import { config } from "@fortawesome/fontawesome-svg-core";
import "@fortawesome/fontawesome-svg-core/styles.css";

// Prevent Font Awesome from adding its CSS since we did it manually above
config.autoAddCss = false;

// Add all icons to the library
library.add(fas, far);

interface TimelineItem {
  year: string
  title: string
  image: string
  icon: {
    prefix: IconPrefix
    iconName: IconName // Use the IconName type
    size: any
    color: string
  }
  side: "left" | "right"
}

const timelineData: TimelineItem[] = [
  {
    year: "1982",
    title: "First Tyre Produced",
    image:
      "https://tvseurogrip.com/wp-content/uploads/2022/02/timeline-1982-image-moped.png",
    icon: {
      prefix: "far",
      iconName: "compass",
      size: "2x",
      color: "white",
    },
    side: "left",
  },
  {
    year: "1991",
    title: "Started Exports",
    image:
      "https://tvseurogrip.com/wp-content/uploads/2022/02/timeline-1991-image-started-exports.png",
    icon: {
      prefix: "fas",
      iconName: "globe-americas",
      size: "2x",
      color: "white",
    },
    side: "right",
  },
  {
    year: "1996",
    title: "ISO Certification",
    image:
      "https://tvseurogrip.com/wp-content/uploads/2022/02/timeline-1996-image-iso-certification.png",
    icon: {
      prefix: "fas",
      iconName: "award",
      size: "2x",
      color: "white",
    },
    side: "left",
  },
  {
    year: "2000",
    title: "ISO 14001 Environmental Management System",
    image:
      "https://tvseurogrip.com/wp-content/uploads/2022/02/timeline-2000-image-iso-environmental-mgmt.png",
    icon: {
      prefix: "fas",
      iconName: "tree",
      size: "2x",
      color: "white",
    },
    side: "right",
  },
  {
    year: "2003",
    title: "TPM Excellence Award",
    image:
      "https://tvseurogrip.com/wp-content/uploads/2022/02/timeline-2003-image-tpm-excellence-award.png",
    icon: {
      prefix: "fas",
      iconName: "trophy",
      size: "2x",
      color: "white",
    },
    side: "left",
  },
  {
    year: "2008",
    title: "New Plant at Uttarakhand",
    image:
      "https://tvseurogrip.com/wp-content/uploads/2022/02/timeline-2008-image-new-plant-uttarkand.png",
    icon: {
      prefix: "far",
      iconName: "building",
      size: "2x",
      color: "white",
    },
    side: "right",
  },
  {
    year: "2009",
    title: "Manufacturing Excellence Award",
    image:
      "https://tvseurogrip.com/wp-content/uploads/2022/02/timeline-2009-image-mfg-excellence-award.png",
    icon: {
      prefix: "fas",
      iconName: "wrench",
      size: "2x",
      color: "white",
    },
    side: "left",
  },
  {
    year: "2015",
    title: "Launched Motorcycle Radials",
    image:
      "https://tvseurogrip.com/wp-content/uploads/2022/02/timeline-2015-image-radials-launch.png",
    icon: {
      prefix: "fas",
      iconName: "motorcycle",
      size: "2x",
      color: "white",
    },
    side: "right",
  },
  {
    year: "2019",
    title: "Introduction Of Steel Radials",
    image:
      "https://tvseurogrip.com/wp-content/uploads/2022/02/timeline-2019-image-STEEL-RADIALS.png",
    icon: {
      prefix: "fas",
      iconName: "database",
      size: "2x",
      color: "white",
    },
    side: "left",
  },
];

export default function VerticalTimeline() {
  // Track which items are visible
  const [visibleItems, setVisibleItems] = useState<boolean[]>(
    Array(timelineData.length).fill(false)
  );

  // Track the current active item
  const [currentItemIndex, setCurrentItemIndex] = useState<number>(-1);

  // Track the progress of the timeline line
  const [lineProgress, setLineProgress] = useState(0);

  // For client-side only rendering of icons
  const [isClient, setIsClient] = useState(false);

  const timelineRef = useRef<HTMLDivElement>(null);
  const itemRefs = useRef<(HTMLDivElement | null)[]>([]);
  const containerRef = useRef<HTMLDivElement>(null);

  useEffect(() => {
    setIsClient(true);
    const currentRefs = itemRefs.current;
    // Function to calculate how far down the page we've scrolled (0 to 1)
    const calculateScrollProgress = () => {
      if (!containerRef.current) return;

      const rect = containerRef.current.getBoundingClientRect();
      const windowHeight = window.innerHeight;

      // When the top of the container is at the bottom of the viewport, progress is 0
      // When the bottom of the container is at the top of the viewport, progress is 1
      const totalDistance = rect.height + windowHeight;
      const scrolledDistance = windowHeight - rect.top;

      const progress = Math.max(
        0,
        Math.min(1, scrolledDistance / totalDistance)
      );
      setLineProgress(progress);
    };

    // Set up intersection observer for each timeline item
    const observer = new IntersectionObserver(
      (entries) => {
        // Update visible items
        entries.forEach((entry) => {
          const index = currentRefs.findIndex(
            (ref) => ref === entry.target
          );
          if (index !== -1) {
            setVisibleItems((prev) => {
              const newState = [...prev];
              newState[index] = entry.isIntersecting;
              return newState;
            });

            // If this item is entering the viewport and we don't have a current item yet,
            // or if this item is more visible than the current one, make it the current item
            if (entry.isIntersecting) {
              setCurrentItemIndex(index);
            } else if (index === currentItemIndex) {
              // If the current item is no longer visible, find the next visible item
              setVisibleItems((prev) => {
                const nextVisibleIndex = prev.findIndex(
                  (isVisible, i) => isVisible && i !== index
                );
                if (nextVisibleIndex !== -1) {
                  setCurrentItemIndex(nextVisibleIndex);
                }
                return prev;
              });
            }
          }
        });
      },
      {
        threshold: 0.2,
        rootMargin: "-100px 0px -100px 0px", // Trigger a bit before the item enters the viewport
      }
    );

    // Observe each timeline item
    currentRefs.forEach((ref) => {
      if (ref) observer.observe(ref);
    });

    // Set up scroll listener for line progress
    window.addEventListener("scroll", calculateScrollProgress);
    calculateScrollProgress(); // Initial calculation

    return () => {
      currentRefs.forEach((ref) => {
        if (ref) observer.unobserve(ref);
      });
      window.removeEventListener("scroll", calculateScrollProgress);
    };
  }, [currentItemIndex]);

  return (
    <div
      ref={containerRef}
      className="relative max-w-7xl mx-auto px-4 sm:px-6 lg:px-8 py-16"
    >
      <h1 className="text-tegblue text-center text-4xl font-semibold mb-[4%]">
        Our Milestones
      </h1>
      {/* Vertical Line with scroll-based animation */}
      <div
        ref={timelineRef}
        className="absolute left-1/2 transform -translate-x-1/2 h-full w-px bg-blue-100"
      >
        <div
          className="bg-blue-200 w-full transition-all duration-700 ease-out"
          style={{ height: `${lineProgress * 100}%` }}
        />
      </div>

      <div className="relative">
        {timelineData.map((item, index) => (
          <div
            key={item.year}
            ref={(el:any) => (itemRefs.current[index] = el)}
            className="mb-24 last:mb-0"
          >
            <div
              className={`flex items-center justify-center ${
                item.side === "left" ? "flex-row" : "flex-row-reverse"
              }`}
            >
              {/* Content Side - Conversation Box Style */}
              <div
                className={`w-5/12 ${
                  item.side === "left" ? "text-right pr-12" : "text-left pl-12"
                }`}
              >
                <div
                  className={`
                  inline-block w-full max-w-md relative
                  ${item.side === "right" ? "ml-auto" : "mr-auto"}
                  transition-all duration-700 ease-out
                  ${
                    visibleItems[index]
                      ? "opacity-100 translate-x-0"
                      : item.side === "left"
                      ? "opacity-0 -translate-x-16"
                      : "opacity-0 translate-x-16"
                  }
                `}
                >
                  {/* Conversation Box */}
                  <div className="bg-white p-6 rounded-2xl shadow-lg border border-gray-300 relative">
                    <Image
                      src={item.image || "/placeholder.svg"}
                      alt={item.title}
                      width={500}
                      height={200}
                      className="w-full h-auto object-contain mb-4"
                    />
                    <h3 className="text-gray-700 font-medium text-2xl text-left mt-2">
                      {item.title}
                    </h3>

                    {/* Conversation Box Pointer */}
                    <div
                      className={`
                      absolute top-1/2 -mt-3 w-4 h-4 bg-white border-t border-r border-gray-300
                       ${
                        item.side === "left" ? "right-[-8px] transform rotate-45" : "left-[-8px] transform rotate-[225deg]"
                      }
                    `}
                    ></div>
                  </div>
                </div>
              </div>

              {/* Timeline Point with animation */}
              <div className="relative flex items-center justify-center w-10 h-10 z-10">
                <div
                  className={`
                    flex justify-center items-center
                    absolute w-16 h-16 rounded-full border-4 
                    transition-all duration-500 ease-out
                    ${
                      !visibleItems[index]
                        ? "bg-blue-200 scale-0"
                        : index === currentItemIndex
                        ? "bg-red-500 scale-100 animate-pulse-subtle"
                        : "bg-[#e8e8f6] scale-100"
                    }
                  `}
                >
                  {isClient && (
                    <FontAwesomeIcon
                      icon={[item.icon.prefix, item.icon.iconName]}
                      size={item.icon.size}
                      color={item.icon.color}
                    />
                  )}
                </div>
              </div>

              {/* Year Side */}
              <div
                className={`w-5/12 ${
                  item.side === "left" ? "text-left pl-12" : "text-right pr-12"
                }`}
              >
                <span
                  className={`
                  text-tegblue text-6xl font-semibold block
                  transition-all duration-700 ease-out
                  ${
                    visibleItems[index]
                      ? "opacity-100 translate-y-0"
                      : "opacity-0 translate-y-10"
                  }
                `}
                >
                  {item.year}
                </span>
              </div>
            </div>
          </div>
        ))}
      </div>

      {/* Custom animation keyframes */}
      <style jsx global>{`
        @keyframes pulseSubtle {
          0% {
            box-shadow: 0 0 0 0 rgba(239, 68, 68, 0.4);
          }
          70% {
            box-shadow: 0 0 0 10px rgba(239, 68, 68, 0);
          }
          100% {
            box-shadow: 0 0 0 0 rgba(239, 68, 68, 0);
          }
        }

        .animate-pulse-subtle {
          animation: pulseSubtle 2s infinite;
        }
      `}</style>
    </div>
  );
}
