/**
 * Extracts HTTP status code from various error types
 * @param error The error to extract status code from
 * @returns The HTTP status code or 500 if not found
 */
export function extractStatusCode(error: unknown): number {
  // Default status code
  const statusCode = 500

  if (!error) return statusCode

  // Handle Error objects with message containing status code
  if (error instanceof Error) {
    // Check for status code in error message (e.g., "Failed to fetch: 404 Not Found")
    const statusMatch = error.message.match(/(\d{3})/)
    if (statusMatch && statusMatch[1]) {
      return Number.parseInt(statusMatch[1], 10)
    }

    // Check for custom status property that might have been added
    const errorWithStatus = error as Error & { status?: number }
    if (errorWithStatus.status) {
      return errorWithStatus.status
    }
  }

  // Handle response-like objects
  const errorAsAny = error as any
  if (errorAsAny?.status && typeof errorAsAny.status === "number") {
    return errorAsAny.status
  }

  // Handle objects with statusCode property
  if (errorAsAny?.statusCode && typeof errorAsAny.statusCode === "number") {
    return errorAsAny.statusCode
  }

  return statusCode
}

/**
 * Creates a custom error with status code
 * @param message Error message
 * @param statusCode HTTP status code
 * @returns Error object with status code
 */
export function createHttpError(message: string, statusCode: number): Error & { status: number } {
  const error = new Error(message) as Error & { status: number }
  error.status = statusCode
  return error
}

