import { type ClassValue, clsx } from 'clsx';
import { twMerge } from 'tailwind-merge';

export function cn(...inputs: ClassValue[]) {
  return twMerge(clsx(inputs));
}

export function cleanupTitle(title: string) {
  const text = title.replaceAll('-', ' ');
  return text.charAt(0).toUpperCase() + text.substring(1);
}

export function generateYearsArray(startYear: number): number[] {
  const currentYear = new Date().getFullYear();
  const yearsArray = [];

  for (let year = startYear; year <= currentYear; year++) {
    yearsArray.push(year);
  }

  return yearsArray;
}

export function generateYearRange(
  startYear: number,
  endYear: number
): string[] {
  let yearRange = [];

  for (let year = startYear; year <= endYear; year++) {
    let nextYearShort = String(year + 1).slice(-2); // Extract the last two digits of the next year
    yearRange.push(`${year}-${nextYearShort}`);
  }

  return yearRange;
}

export function decodeSlug(slug: string): string {
  return slug
    .split('-') // Split the slug into words at hyphens
    .map((word) => word.charAt(0).toUpperCase() + word.slice(1)) // Capitalize each word
    .join(' '); // Join the words back with spaces
}

export const generateOrderNumber = () => {
  const date = new Date();
  const year = date.getFullYear();
  const month = String(date.getMonth() + 1).padStart(2, '0');
  const day = String(date.getDate()).padStart(2, '0');
  const hours = String(date.getHours()).padStart(2, '0');
  const minutes = String(date.getMinutes()).padStart(2, '0');
  const seconds = String(date.getSeconds()).padStart(2, '0');
  const randomDigits = Math.floor(Math.random() * 1000)
    .toString()
    .padStart(3, '0');

  return `ORD-${year}${month}${day}-${hours}${minutes}${seconds}-${randomDigits}`;
};

type FormatOptions = 'date' | 'time' | 'datetime';

export function formatDate(
  dateString: string,
  option: FormatOptions = 'datetime'
): string {
  const date = new Date(dateString);

  if (isNaN(date.getTime())) {
    throw new Error('Invalid date string');
  }

  const dateOptions: Intl.DateTimeFormatOptions = {
    year: 'numeric',
    month: 'long',
    day: 'numeric',
  };

  const timeOptions: Intl.DateTimeFormatOptions = {
    hour: 'numeric',
    minute: 'numeric',
    hour12: true,
  };

  switch (option) {
    case 'date':
      return new Intl.DateTimeFormat('en-US', dateOptions).format(date);
    case 'time':
      return new Intl.DateTimeFormat('en-US', timeOptions).format(date);
    case 'datetime':
      return `${new Intl.DateTimeFormat('en-US', dateOptions).format(
        date
      )}, ${new Intl.DateTimeFormat('en-US', timeOptions).format(date)}`;
    default:
      throw new Error('Invalid option');
  }
}

export const truncateString = (str: string, maxLength: number): string => {
  if (str.length <= maxLength) return str;
  return str.slice(0, maxLength) + '...';
};
