import { create } from 'zustand';

// Update the BlogPost type to match the actual API response structure
export type BlogPost = {
  id: number;
  attributes: {
    Headline: string;
    Slug: string;
    RichText: string;
    createdAt: string;
    updatedAt: string;
    publishedAt: string;
    publisheddate: string;
    FeaturedImage: {
      data: {
        attributes: {
          url: string;
          formats: {
            small: {
              url: string;
            };
            medium: {
              url: string;
            };
            thumbnail: {
              url: string;
            };
          };
        };
      };
    };
    blog_category: {
      data: {
        id: number;
        attributes: {
          Categoryname: string;
          slug: string;
        };
      };
    };
    blog_subcategory: {
      data: {
        id: number;
        attributes: {
          name: string;
          slug: string;
        } | null;
      };
    };
  };
};

export type Category = {
  id: number;
  attributes: {
    Categoryname: string;
    slug: string;
  };
};

export type SubCategory = {
  id: number;
  attributes: {
    name: string;
    slug: string;
    blog_category?: {
      data: {
        id: number;
        attributes: {
          slug: string;
        };
      };
    };
  };
};

type BlogStore = {
  blogs: BlogPost[];
  categories: Category[];
  subcategories: SubCategory[];
  selectedCategory: string | null;
  selectedSubcategory: string | null;
  isLoading: boolean;
  setSelectedCategory: (category: string | null) => void;
  setSelectedSubcategory: (subcategory: string | null) => void;
  fetchBlogs: () => Promise<void>;
  fetchCategories: () => Promise<void>;
  fetchSubcategories: () => Promise<void>;
};

export const useBlogStore = create<BlogStore>((set, get) => ({
  blogs: [],
  categories: [],
  subcategories: [],
  selectedCategory: null,
  selectedSubcategory: null,
  isLoading: false,

  setSelectedCategory: (category) => {
    set({ selectedCategory: category, selectedSubcategory: null });
    get().fetchBlogs();
  },

  setSelectedSubcategory: (subcategory) => {
    set({ selectedSubcategory: subcategory });
    get().fetchBlogs();
  },

  fetchBlogs: async () => {
    const { selectedCategory, selectedSubcategory } = get();
    set({ isLoading: true });

    try {
      let url = `${process?.env?.NEXT_PUBLIC_PROD_API_URL}/api/v1/blogs?`;

      if (selectedCategory) {
        url += `category=${selectedCategory}&`;
      }

      if (selectedSubcategory) {
        url += `subcategory=${selectedSubcategory}&`;
      }

      const response = await fetch(url);
      const data = await response.json();

      set({ blogs: data.data || [], isLoading: false });
    } catch (error) {
      console.error('Error fetching blogs:', error);
      set({ isLoading: false });
    }
  },

  fetchCategories: async () => {
    try {
      const response = await fetch(
        `${process?.env?.NEXT_PUBLIC_PROD_API_URL}/api/v1/blogs/categories`
      );
      const data = await response.json();

      set({ categories: data.data || [] });
    } catch (error) {
      console.error('Error fetching categories:', error);
    }
  },

  fetchSubcategories: async () => {
    try {
      const response = await fetch(
        `${process?.env?.NEXT_PUBLIC_PROD_API_URL}/api/v1/blogs/subcategories`
      );
      const data = await response.json();

      set({ subcategories: data.data || [] });
    } catch (error) {
      console.error('Error fetching subcategories:', error);
    }
  },
}));
