import { create } from 'zustand';
import { persist } from 'zustand/middleware';

interface Product {
  id: string;
  title: string;
  sku: string;
  permalink: string;
  price: string;
  image: string;
}

interface CartItem extends Product {
  quantity: number;
}

interface Coupon {
  code: string;
  discount: number; // Percentage discount
}

interface CartStore {
  items: CartItem[];
  coupon: Coupon | null;
  addItemCart: (product: Product, quantity?: number) => void;
  removeItemCart: (id: string) => void;
  increaseQuantity: (id: string) => void;
  decreaseQuantity: (id: string) => void;
  clearCart: () => void;
  applyCoupon: (code: string) => void;
  removeCoupon: () => void;
  total: () => number;
  discountedTotal: () => number;
}

const coupons: Coupon[] = [
  { code: 'SAVE10', discount: 10 },
  { code: 'SAVE20', discount: 20 },
  { code: 'SAVE99', discount: 99 },
];

export const useCartStore = create(
  persist<CartStore>(
    (set, get) => ({
      items: [],
      coupon: null,
      addItemCart: (product, quantity = 1) =>
        set((state) => {
          const existingItem = state.items.find(
            (item) => item.id === product.id
          );
          if (existingItem) {
            return {
              items: state.items.map((item) =>
                item.id === product.id
                  ? { ...item, quantity: item.quantity + quantity }
                  : item
              ),
            };
          } else {
            return { items: [...state.items, { ...product, quantity }] };
          }
        }),
      removeItemCart: (id) =>
        set((state) => ({
          items: state.items.filter((item) => item.id !== id),
        })),
      increaseQuantity: (id) =>
        set((state) => ({
          items: state.items.map((item) =>
            item.id === id ? { ...item, quantity: item.quantity + 1 } : item
          ),
        })),
      decreaseQuantity: (id) =>
        set((state) => ({
          items: state.items
            .map((item) =>
              item.id === id && item.quantity > 1
                ? { ...item, quantity: item.quantity - 1 }
                : item
            )
            .filter((item) => item.quantity > 0),
        })),
      clearCart: () => set({ items: [], coupon: null }),
      applyCoupon: (code) =>
        set((state) => {
          const coupon = coupons.find((c) => c.code === code);
          return coupon ? { coupon } : state;
        }),
      removeCoupon: () => set({ coupon: null }),
      total: () => {
        const items = get().items;
        return items.reduce(
          (total, item) =>
            total + Number.parseFloat(item.price) * item.quantity,
          0
        );
      },
      discountedTotal: () => {
        const total = get().total();
        const coupon = get().coupon;
        return coupon ? total * (1 - coupon.discount / 100) : total;
      },
    }),
    {
      name: 'cart-storage',
      // getStorage: () => localStorage,
    }
  )
);
