import { create } from 'zustand';

// Define the filter state type
interface FilterState {
  // Filter values
  selectedBrand: string;
  selectedModel: string;
  selectedTyrePos: string;
  selectedFrontTyreSize: string;
  selectedRearTyreSize: string;
  selectedPattern: string;
  selectedSegment: string;

  // Actions to update filters
  setBrand: (brand: string) => void;
  setModel: (model: string) => void;
  setTyrePos: (position: string) => void;
  setFrontTyreSize: (size: string) => void;
  setRearTyreSize: (size: string) => void;
  setPattern: (pattern: string) => void;
  setSegment: (segment: string) => void;
  resetFilter: (filterName: string) => void;
  resetAllFilters: () => void;

  // Computed values
  getFilters: () => { [key: string]: string | null };
  filterSelector: { [key: string]: string };
}

// Default values for filters
const DEFAULT_VALUES = {
  selectedBrand: 'Select brand',
  selectedModel: 'Select model',
  selectedTyrePos: 'Select tyre position',
  selectedFrontTyreSize: 'Select Front Tyre Size',
  selectedRearTyreSize: 'Select Rear Tyre Size',
  selectedPattern: 'Select Pattern',
  selectedSegment: 'Select Product Segment',
};

// Create the Zustand store
const useProductFilterStore = create<FilterState>((set, get) => ({
  // Initial state
  ...DEFAULT_VALUES,

  // Actions
  setBrand: (brand) => set({ selectedBrand: brand }),
  setModel: (model) => set({ selectedModel: model }),
  setTyrePos: (position) => set({ selectedTyrePos: position }),
  setFrontTyreSize: (size) => set({ selectedFrontTyreSize: size }),
  setRearTyreSize: (size) => set({ selectedRearTyreSize: size }),
  setPattern: (pattern) => set({ selectedPattern: pattern }),
  setSegment: (segment) => set({ selectedSegment: segment }),

  // Reset a specific filter to its default value
  resetFilter: (filterName) => {
    const key = `selected${
      filterName.charAt(0).toUpperCase() + filterName.slice(1)
    }` as keyof typeof DEFAULT_VALUES;
    if (key in DEFAULT_VALUES) {
      set({ [key]: DEFAULT_VALUES[key] } as any);
    }
  },

  // Reset all filters to default values
  resetAllFilters: () => set(DEFAULT_VALUES),

  // Get all filters as an object with null for unselected filters
  getFilters: () => {
    const state = get();
    return {
      brand:
        state.selectedBrand !== DEFAULT_VALUES.selectedBrand
          ? state.selectedBrand
          : null,
      model:
        state.selectedModel !== DEFAULT_VALUES.selectedModel
          ? state.selectedModel
          : null,
      tyrePos:
        state.selectedTyrePos !== DEFAULT_VALUES.selectedTyrePos
          ? state.selectedTyrePos
          : null,
      frontTyreSize:
        state.selectedFrontTyreSize !== DEFAULT_VALUES.selectedFrontTyreSize
          ? state.selectedFrontTyreSize
          : null,
      rearTyreSize:
        state.selectedRearTyreSize !== DEFAULT_VALUES.selectedRearTyreSize
          ? state.selectedRearTyreSize
          : null,
      pattern:
        state.selectedPattern !== DEFAULT_VALUES.selectedPattern
          ? state.selectedPattern
          : null,
      segment:
        state.selectedSegment !== DEFAULT_VALUES.selectedSegment
          ? state.selectedSegment
          : null,
    };
  },

  // Filter selector mapping
  filterSelector: {
    brand: 'Compatible Vehicle List',
    model: 'Compatible Vehicle List',
    tyrePos: 'Wheel Position',
    rearTyreSize: 'Rear Tyre Size',
    frontTyreSize: 'Front Tyre Size',
    pattern: 'Product Pattern',
    segment: 'Product Segmentation',
  },
}));

export default useProductFilterStore;
